aboutsummaryrefslogtreecommitdiffstats
path: root/include
diff options
context:
space:
mode:
authorPiotr Krysik <ptrkrysik@gmail.com>2016-08-30 21:31:24 +0200
committerPiotr Krysik <ptrkrysik@gmail.com>2016-08-30 21:31:24 +0200
commita3405b285dd088ad2e31964e27f3cb0812ca735a (patch)
tree8a1fc8e3171b36af7cb71e33bd33f54b00b15b81 /include
parentd61f85ba6dfa64909df32e4927e7acf35f2d1d1f (diff)
Changed path (flow_control) and name of uplink_downlink_filter to splitter
Diffstat (limited to 'include')
-rw-r--r--include/grgsm/CMakeLists.txt3
-rw-r--r--include/grgsm/flow_control/CMakeLists.txt3
-rw-r--r--include/grgsm/flow_control/uplink_downlink_splitter.h (renamed from include/grgsm/uplink_downlink_filter.h)16
3 files changed, 11 insertions, 11 deletions
diff --git a/include/grgsm/CMakeLists.txt b/include/grgsm/CMakeLists.txt
index 61f15bf..dc9b191 100644
--- a/include/grgsm/CMakeLists.txt
+++ b/include/grgsm/CMakeLists.txt
@@ -23,8 +23,7 @@
install(FILES
plotting.hpp
api.h
- gsmtap.h
- uplink_downlink_filter.h DESTINATION include/grgsm
+ gsmtap.h DESTINATION include/grgsm
)
add_subdirectory(decoding)
diff --git a/include/grgsm/flow_control/CMakeLists.txt b/include/grgsm/flow_control/CMakeLists.txt
index a4156a4..9c20b59 100644
--- a/include/grgsm/flow_control/CMakeLists.txt
+++ b/include/grgsm/flow_control/CMakeLists.txt
@@ -26,5 +26,6 @@ install(FILES
burst_timeslot_filter.h
burst_sdcch_subslot_filter.h
burst_fnr_filter.h
- dummy_burst_filter.h DESTINATION include/grgsm/flow_control
+ dummy_burst_filter.h
+ uplink_downlink_splitter.h DESTINATION include/grgsm/flow_control
)
diff --git a/include/grgsm/uplink_downlink_filter.h b/include/grgsm/flow_control/uplink_downlink_splitter.h
index dec4af6..c8f1321 100644
--- a/include/grgsm/uplink_downlink_filter.h
+++ b/include/grgsm/flow_control/uplink_downlink_splitter.h
@@ -21,8 +21,8 @@
*/
-#ifndef INCLUDED_GRGSM_UPLINK_DOWNLINK_FILTER_H
-#define INCLUDED_GRGSM_UPLINK_DOWNLINK_FILTER_H
+#ifndef INCLUDED_GRGSM_UPLINK_DOWNLINK_SPLITTER_H
+#define INCLUDED_GRGSM_UPLINK_DOWNLINK_SPLITTER_H
#include <grgsm/api.h>
#include <gnuradio/block.h>
@@ -35,17 +35,17 @@ namespace gr {
* \ingroup grgsm
*
*/
- class GRGSM_API uplink_downlink_filter : virtual public gr::block
+ class GRGSM_API uplink_downlink_splitter : virtual public gr::block
{
public:
- typedef boost::shared_ptr<uplink_downlink_filter> sptr;
+ typedef boost::shared_ptr<uplink_downlink_splitter> sptr;
/*!
* \brief Return a shared_ptr to a new instance of grgsm::uplink_downlink_filter.
*
* To avoid accidental use of raw pointers, grgsm::uplink_downlink_filter's
* constructor is in a private implementation
* class. grgsm::uplink_downlink_filter::make is the public interface for
* creating new instances.
*/
static sptr make();
@@ -54,5 +54,5 @@ namespace gr {
} // namespace grgsm
} // namespace gr
-#endif /* INCLUDED_GRGSM_UPLINK_DOWNLINK_FILTER_H */
+#endif /* INCLUDED_GRGSM_UPLINK_DOWNLINK_SPLITTER_H */
@@ -35,17 +35,17 @@ namespace gr {
/*!
- * \brief Return a shared_ptr to a new instance of grgsm::uplink_downlink_filter.
+ * \brief Return a shared_ptr to a new instance of grgsm::uplink_downlink_splitter.
*
@@ -35,17 +35,17 @@ namespace gr {
*
- * To avoid accidental use of raw pointers, grgsm::uplink_downlink_filter's
+ * To avoid accidental use of raw pointers, grgsm::uplink_downlink_splitter's
* constructor is in a private implementation
@@ -35,17 +35,17 @@ namespace gr {
* constructor is in a private implementation
- * class. grgsm::uplink_downlink_filter::make is the public interface for
+ * class. grgsm::uplink_downlink_splitter::make is the public interface for
* creating new instances.
*/